@@ -716,6 +716,52 @@ sub command_exist {
 		Debconf::Question->get($question_name) ? "true" : "false";
 }
 
+=item command_progress
+
+Not implemented by debconf itself, but provided for use with cdebconf as a
+passthrough agent. If the frontend does not support this, returns a syntax
+error.
+
+Support for this command in Perl debconf is Ubuntu-specific for now.
+
+=cut
+
+sub command_progress {
+	my $this=shift;
+	return $codes{syntaxerror}, "Incorrect number of arguments" if @_ < 1;
+	my $subcommand=shift;
+	my ($min, $max, $question_name, $question);
+
+	if ($subcommand eq 'START') {
+		return $codes{syntaxerror}, "Incorrect number of arguments" if @_ != 3;
+		$min=$_[0];
+		$max=$_[1];
+		return $codes{syntaxerror}, "min ($min) > max ($max)" if $min > $max;
+		$question_name=$_[2];
+	} elsif ($subcommand eq 'SET') {
+		return $codes{syntaxerror}, "Incorrect number of arguments" if @_ != 1;
+	} elsif ($subcommand eq 'STEP') {
+		return $codes{syntaxerror}, "Incorrect number of arguments" if @_ != 1;
+	} elsif ($subcommand eq 'INFO') {
+		return $codes{syntaxerror}, "Incorrect number of arguments" if @_ != 1;
+		$question_name=$_[0];
+	} elsif ($subcommand eq 'STOP') {
+		return $codes{syntaxerror}, "Incorrect number of arguments" if @_ != 0;
+	}
+
+	if (defined $question_name) {
+		$question=Debconf::Question->get($question_name) ||
+			return $codes{badparams}, "\"$question_name\" doesn't exist";
+	}
+
+	if ($this->frontend->can("progress")) {
+		return $this->frontend->progress($subcommand, $question, @_);
+	} else {
+		return $codes{syntaxerror}.' '.
+		       "Progress bars are not supported by this frontend.";
+	}
+}
+
 =item AUTOLOAD
 
 Handles storing and loading fields.
